@@ -3,8 +3,8 @@
 # when it's destroyed.
 
 package POE::Component::Connection::Keepalive;
-BEGIN {
-  $POE::Component::Connection::Keepalive::VERSION = '0.266';
+{
+  $POE::Component::Connection::Keepalive::VERSION = '0.269';
 }
 
 use warnings;
@@ -99,12 +99,11 @@ __END__
 
 =head1 NAME
 
+POE::Component::Connection::Keepalive - a wheel wrapper around a kept-alive socket
 
 =head1 VERSION
 
-version 0.266
-POE::Component::Connection::Keepalive - a wheel wrapper around a
-kept-alive socket
+version 0.269
 
 =head1 SYNOPSIS
 
@@ -210,4 +209,4 @@ Rocco Caputo <rcaputo@cpan.org>
 
 Special thanks to Rob Bloodgood.
 
-=cut
\ No newline at end of file
+=cut
